from conans import ConanFile, CMake, tools

class HelloQtConan(ConanFile):
    name = "HelloQt"
    settings = "os", "compiler", "build_type", "arch"
    requires = (
        "qt/5.12.10"
    )
    generators = "cmake_paths"
    scm = {
        "type": "git",
        "url": "auto",
        "revision": "auto"
    }

    def set_version(self):
        try:
            git = tools.Git(folder=self.recipe_folder)
            tag = git.get_tag()
            if tag:
                if tag[0] == 'v':
                    self.version = tag[1:]
                else:
                    self.version = tag
            else:
                self.version = git.get_revision()[:7]
        except Exception as ex:
            print("Exception in set_version(): "+str(ex))
            self.version = "undef"

    def _configure_cmake(self):
        cmake = CMake(self)
        # cmake.generator = "Ninja"
        # cmake.definitions['CMAKE_BUILD_TYPE'] = self.settings.build_type
        cmake.configure()
        return cmake

    def build(self):
        cmake = self._configure_cmake()
        cmake.build()

    def package(self):
        cmake = self._configure_cmake()
        cmake.install()

    def deploy(self):
        self.copy("*", dst=self.name, src="bin")
        self.copy_deps("*LICENSE*", dst=self.name+"/licenses", src="licenses", folder=True)
        self.copy_deps("*COPYING*", dst=self.name+"/licenses", src="licenses", folder=True)
        if self.settings.os == "Windows":
            self.copy_deps("*.dll", dst=self.name, src="bin")
            self.copy_deps("*.dll", dst=self.name+"/plugins", src="plugins")
        else:
            self.copy_deps("*.so", dst=self.name, src="lib")
            self.copy_deps("*.so", dst=self.name+"/plugins", src="plugins")
        with open(self.name+"/qt.conf", "w") as f_qt_conf:
            f_qt_conf.write("[Paths]\n")
            f_qt_conf.write("Prefix=.\n")
            f_qt_conf.write("Binaries=.\n")
            f_qt_conf.write("Libraries=.\n")
            f_qt_conf.write("Plugins=plugins\n")
